@@ -16,6 +16,7 @@ getInternals <- function()
     mylist <- ls(parent.frame())
     ##  print(mylist)
     library(codetools)
+	## fnlist has a row number at the front: column 3 contains the function names
     mylist <- mylist[mylist %in% fnlist[, 3]]
     mytt <- lapply(mylist, function(x)
        {
@@ -39,26 +40,36 @@ getInternals <- function()
 ##@getRSienaDocumentation Documentation
 getRSienaRDocumentation <- function(Rdir)
 {
-   # library(xtable)
+	library(xtable)
     library(codetools)
 
     thisdir <- getwd()
     ## temporarily move directory
+	on.exit(setwd(thisdir))
     setwd(Rdir)
 
     ## extract comment lines
-    shell('grep "##@" *.r *.R > comments.lis')
+    if (.Platform$OS.type == "windows")
+    {
+        shell('grep "##@" *.r *.R > comments.lis')
+    }
+    else
+    {
+        system('grep "##@" *.r *.R > comments.lis')
+    }
     ## read them in
     comms <- readLines('comments.lis')
     ## remove the file
     file.remove("comments.lis")
     ## remove the shell line
     comms <- comms[!grepl("comments.lis", comms)]
+	## get rid of tabs
+	comms <- gsub("\t", "", comms)
     ## split off
     mystr <- paste("##", "@", sep="")
     comms1 <- strsplit(comms, mystr)
     ## join up rest
-    comms2 <- do.call(rbind, comms1)
+    ## comms2 <- do.call(rbind, comms1)
     ## turn into dataframe
     comms3 <- sapply(comms1, function(x)
                  {
@@ -70,7 +81,7 @@ getRSienaRDocumentation <- function(Rdir)
                      }
                      else
                      {
-                         c(x[1], tmp[1], tmp[2], paste(tmp[-c(1,2)],
+                         c(x[1], tmp[1], tmp[2], paste(tmp[-c(1, 2)],
                                                        collapse=" "))
                      }
                  }
@@ -96,27 +107,55 @@ getRSienaRDocumentation <- function(Rdir)
 
     ## now the internal ones
     ## find the list of files from comms3
+#	browser()
+	internals <- comms3[grepl("internal to", comms3[, 4]), ]
     ttmp <- unique(comms3[grepl("internal to", comms3[, 4]), 4])
-    ttmp <- sub("internal to ", "", ttmp)
-    ttmp2 <- comms3[match(ttmp, comms3[, 2]), 1]
-    ttmp2 <- sub(":", "", ttmp2)
-
+    ttmp1 <- sub("internal to ", "", ttmp)
+	ttmp3 <- lapply(ttmp1, function(x)
+				{
+					tmp <- x
+					while(!is.na(sub <- match(tmp[1], internals[, 2])))
+					{
+						tmp1 <- internals[sub, 4]
+						tmp1 <- sub("internal to ", "", tmp1)
+						tmp <- c(tmp1, tmp)
+					}
+					tmp
+				})
+    #ttmp2 <- comms3[match(ttmp1, comms3[, 2]), 1]
+    #ttmp2 <- sub(":", "", ttmp2)
     ## write out the fnlist in the Rdir
     write.csv(data.frame(comms3), "RSienafnlist.csv")
     ## get the list of internals
-    tt <- lapply(1:length(ttmp), function(x, y, z)
-             {
-                 yy <- y[x]
-                 zz <- z[[x]]
-                 yy <- getFromNamespace(yy, pkgname)
+	tt <- lapply(ttmp3, function(x)
+			 {
+				 yy <- getFromNamespace(x[1], pkgname)
                  targs <- formals(yy)
-                 n <- length(targs)
-                 myargs <- targs
-                 for (i in 1:n)
-                     myargs[[i]] <- 1
-                 myargs['getDocumentation'] <- TRUE
-                 do.call(yy, myargs)
-             }, y=ttmp, z=ttmp2)
+				 targs[1:length(targs)] <- 1
+				 if (length(x) > 1)
+				 {
+					 targs['getDocumentation'] <- x[-1]
+				 }
+				 else
+				 {
+					 targs['getDocumentation'] <- TRUE
+				 }
+                 do.call(yy, targs)
+			 })
+    #tt <- lapply(1:length(ttmp3), function(x, y)
+    #         {
+    #             yy <- y[x]
+    #             yy <- getFromNamespace(yy, pkgname)
+    #             targs <- formals(yy)
+    #             n <- length(targs)
+    #             myargs <- targs
+    #             for (i in 1:n)
+#				 {
+#                     myargs[[i]] <- 1#
+				 #}
+                 #myargs['getDocumentation'] <- TRUE
+                 #do.call(yy, myargs)
+             #}, y=ttmp)
     names(tt) <- ttmp
     ## remove the file
     file.remove("RSienafnlist.csv")
@@ -126,7 +165,7 @@ getRSienaRDocumentation <- function(Rdir)
                   yy <- y[[x]]
                   n <- length(y[[x]])
                   bb <- names(yy)
-                  t1<- lapply(1:length(yy), function(x,  b, a)
+                  t1<- lapply(1:n, function(x,  b, a)
                           {
                               y <- a[[x]]
                               bb <- b[[x]]
@@ -136,7 +175,7 @@ getRSienaRDocumentation <- function(Rdir)
                               else
                                   c( bb, " ")
                           },  a=yy, b=bb)
-                  t2 <- do.call(rbind,t1)
+                  do.call(rbind,t1)
               }, y=tt
                   )
 
@@ -200,7 +239,7 @@ getRSienaRDocumentation <- function(Rdir)
     names(tttt7) <- c("Called from", "Function")
     tttt7 <- tttt7[order(tttt7[,2],tttt7[,1]), ]
 
-    tmp7bit <- tmp7[tmp7$Function %in% tttt7$Function, ]
+   ## tmp7bit <- tmp7[tmp7$Function %in% tttt7$Function, ]
 
     tmp7new <- merge(tmp7, tttt7, by=c("Function", "Called from"), all=TRUE)
 
@@ -241,7 +280,7 @@ getRSienaRDocumentation <- function(Rdir)
     tmp12 <- do.call(rbind, tmp11)
     names(tmp12)[2] <- "Function"
 
-    tmp12 <- tmp12[order(tmp12[, "type"], row.names(tmp12)), ]
+    tmp12 <- tmp12[order(tmp12[, "type"], as.numeric(row.names(tmp12))), ]
     tmp12 <- tmp12[, c(3, 2, 5, 6, 4, 1)]
     ff <- xtable(tmp12)
     ## go back to start directory
