@@ -1,7 +1,7 @@
 #/******************************************************************************
 # * SIENA: Simulation Investigation for Empirical Network Analysis
 # *
-# * Web: http://www.stats.ox.ac.uk/~snidjers/siena
+# * Web: http://www.stats.ox.ac.uk/~snijders/siena
 # *
 # * File: effectsDocumentation.r
 # *
@@ -10,18 +10,34 @@
 # *****************************************************************************/
 
 ##@effectsDocumentation Documentation
-effectsDocumentation <- function(type="html", display=type=="html",
-                                 filename="effects")
+effectsDocumentation <- function(effects= NULL, type="html", display=(type=="html"),
+     filename=ifelse(is.null(effects), "effects", deparse(substitute(effects))))
 {
+	if (is.null(effects))
+	{
     x <- allEffects[, c("effectGroup", "effectName", "shortName",
                         "endowment", "interaction1", "interaction2",
                         "parm", "interactionType")]
+	}
+	else
+	{
+    x <- as.data.frame(effects[, c("name", "effectName", "shortName", "type",
+                        "interaction1", "interaction2",
+                        "parm", "interactionType")])
+	}
     storage.mode(x$parm) <- "integer"
-    names(x)[4] <- "endow?"
+    names(x)[4] <- ifelse(is.null(effects), "endow?", "type")
     names(x)[5] <- "inter1"
     names(x)[6] <- "inter2"
-    names(x)[8] <- "ego?"
-    x$row <- as.integer(row.names(x))
+    names(x)[8] <- "interactionType"
+	if (is.null(effects))
+	{
+		x$row <- as.integer(row.names(x))
+	}
+	else
+	{
+		x$row <- 1:dim(x)[1]
+	}
     x <- x[, c(9, 1:8)]
 
     myorder <- c("nonSymmetricRate",
@@ -36,6 +52,7 @@ effectsDocumentation <- function(type="html", display=type=="html",
                  "behaviorRate",
                  "behaviorOneModeRate",
 				 "behaviorSymmetricRate",
+				 "covarBehaviorOneModeRate",
                  "behaviorBipartiteRate",
                  "covarBehaviorRate",
 
@@ -73,6 +90,8 @@ effectsDocumentation <- function(type="html", display=type=="html",
 
     addtorowPos <- cumsum(c(0, mytab[myorder]))[1:length(myorder)]
     addtorowText <- names(mytab[myorder])
+	x[is.na(x)] <- "FALSE" ## endow? field
+
     if (type=="latex")
     {
         addtorowText <- paste(" \\hline \\multicolumn{4}{l}{",
@@ -81,21 +100,25 @@ effectsDocumentation <- function(type="html", display=type=="html",
     }
     else
     {
-        x[is.na(x)] <- "FALSE" ## endow? field
-       x[x==""] <- "<br>"
-         addtorowText <- paste(' <TR> <TD colspan="8" >',
+		x[x==""] <- "<br>"
+		addtorowText <- paste(' <TR> <TD colspan="8" >',
                               addtorowText, "</TD> </TR>")
     }
     add.to.row  <-  NULL
-    add.to.row$pos <- lapply(addtorowPos, function(x)x)
-    add.to.row$command <- as.vector(sapply(addtorowText, function(x)x))
-
-    order2 <- match(myorder, x[, 2])
-    order3 <- as.vector(mytab[myorder])
-
-    order4 <- unlist(apply(cbind(order2, order3), 1,
+    if (is.null(effects))
+	{
+		add.to.row$pos <- lapply(addtorowPos, function(x)x)
+		add.to.row$command <- as.vector(sapply(addtorowText, function(x)x))
+		order2 <- match(myorder, x[, 2])
+		order3 <- as.vector(mytab[myorder])
+		order4 <- unlist(apply(cbind(order2, order3), 1,
                            function(x)x[1]:(x[1] + x[2] -1)))
-    y <- x[order4, -2]
+		y <- x[order4, -2]
+	}
+	else
+	{
+		y <- x
+	}
     row.names(y) <- 1:nrow(y)
 
     if (type =="latex")
