@@ -1,7 +1,7 @@
 #/******************************************************************************
 # * SIENA: Simulation Investigation for Empirical Network Analysis
 # *
-# * Web: http://www.stats.ox.ac.uk/~snidjers/siena
+# * Web: http://www.stats.ox.ac.uk/~snijders/siena
 # *
 # * File: print07report.r
 # *
@@ -13,8 +13,15 @@ PrintReport <- function(z, x)
 {
     types <- attr(z$f, "types")
     Report('\n\n', outf)
-    Heading(2, outf, "Estimation Results.")
-    if (!z$OK)
+	if ((x$nsub == 0)&(x$simOnly))
+	{
+		Heading(2, outf, "Simulation Results.")
+	}
+		else
+    {
+		Heading(2, outf, "Estimation Results.")
+	}
+	if (!z$OK)
    {
        Report("Error end of estimation algorithm", outf)
    }
@@ -23,7 +30,14 @@ PrintReport <- function(z, x)
            Report("Regular end of estimation algorithm.\n", outf)
            Report(c("Total of", z$n, "iteration steps.\n\n"), outf)
            Report(c("Total of", z$n, "iteration steps.\n\n"), bof)
-           Heading(3, outf, "Estimates and standard errors")
+		   if (x$simOnly)
+		   {
+				Heading(3, outf, "Parameter values")
+			}
+			else
+			{
+				Heading(3, outf, "Estimates and standard errors")
+			}
            Heading(3, bof, "Estimates and standard errors")
            if (z$cconditional) ## deal with rate parameter
            {
@@ -81,19 +95,26 @@ PrintReport <- function(z, x)
            {
                Report("Network Dynamics\n", outf)
            }
-           ses <- ifelse(diag(z$covtheta) >= 0.0 | z$fixed,
-                         paste('  (', sprintf("%9.4f",sqrt(diag(z$covtheta))),
+			if (!x$simOnly)
+			{
+				ses <- ifelse(diag(z$covtheta) >= 0.0 | z$fixed,
+						paste('  (', sprintf("%9.4f",sqrt(diag(z$covtheta))),
                                              ')', sep=''), '        ---')
-           if (!all(z$fixed))
-           {
-               ses[z$fixed] <- '  (  fixed  )'
-           }
-           theta <- ifelse(diag(z$covtheta) >= 0.0 | z$fixed,
+				if (!all(z$fixed))
+				{
+					ses[z$fixed] <- '  (  fixed  )'
+				}
+				theta <- ifelse(diag(z$covtheta) >= 0.0 | z$fixed,
                            sprintf("%9.4f",z$theta),
                            '       ---')
-           if (nBehavs > 0)
-           {
-               behEffects <-
+			}		
+			else
+			{
+				theta <- sprintf("%9.4f",z$theta)
+			}
+			if (nBehavs > 0)
+			{
+				behEffects <-
                    z$requestedEffects[z$requestedEffects$netType == 'behavior',]
                behNames <- unique(behEffects$name)
                if (nBehavs > 1)
@@ -108,15 +129,19 @@ PrintReport <- function(z, x)
                                                      behEffects$effectName
                }
            }
-           typesp <- ifelse (z$requestedEffects$type %in% c("eval", "rate"),
+			typesp <- ifelse (z$requestedEffects$type %in% c("eval", "rate"),
                              ":  ", ": ")
-           typetxt <- ifelse (z$requestedEffects$type == "creation", "creat",
+			typetxt <- ifelse (z$requestedEffects$type == "creation", "creat",
                               z$requestedEffects$type )
-           tmp <- paste(typetxt, typesp, z$requestedEffects$effectName, sep = '')
-           tmp <- paste(sprintf("%2d", 1:length(z$requestedEffects$effectName)),
+			tmp <- paste(typetxt, typesp, z$requestedEffects$effectName, sep = '')
+			if (x$simOnly)
+			{
+				ses <- rep('           ', z$pp)
+			}	
+			tmp <- paste(sprintf("%2d", 1:length(z$requestedEffects$effectName)),
                         '. ', format(substr(tmp, 1, 50), width=50),
                         theta, ses, '\n', sep='', collapse = '')
-           if (nBehavs > 0 && nNetworks > 0)
+			if (nBehavs > 0 && nNetworks > 0)
            {
                nNetworkEff <- nrow(z$requestedEffects) - nrow(behEffects)
                tmpstr <- paste(nNetworkEff + 1, '. ', sep='')
@@ -142,38 +167,41 @@ PrintReport <- function(z, x)
                         'the standard errors of rate parameters\n',
                         'not used for conditioning are unreliable.'), outf)
            }
-           Heading(3, outf, "Covariance matrices")
-           if (any(z$fixed))
-           {
-               Report(c('(Values of the covariance matrix of estimates\n',
-                        ' are meaningless for the fixed parameters.)\n\n'),
-                      outf)
-           }
-
-           Report(c("Covariance matrix of estimates",
+			if (!x$simOnly)
+			{
+				Heading(3, outf, "Covariance matrices")
+				if (any(z$fixed))
+				{
+					Report(c('(Values of the covariance matrix of estimates\n',
+						' are meaningless for the fixed parameters.)\n\n'),
+						outf)
+				}
+				Report(c("Covariance matrix of estimates",
                     "(correlations below diagonal):\n"), outf)
-           covcor <- z$covtheta
-           correl <- z$covtheta/sqrt(diag(z$covtheta))[row(z$covtheta)]/
-               sqrt(diag(z$covtheta))[col(z$covtheta)]
-           covcor[lower.tri(covcor)] <- correl[lower.tri(correl)]
-           PrtOutMat(format(round(covcor, digits = 3), width = 10), outf)
-           Report(c('Derivative matrix of expected statistics X by',
-                    'parameters and\n'), outf)
-           Report(c("covariance/correlation matrix of X can be found using\n",
-                    "summary(ans) within R,",
-           " or by using the 'verbose' option in Siena07.\n "), sep = "", outf)
-           Report(c("Derivative matrix of expected statistics X by",
+				covcor <- z$covtheta
+				correl <- z$covtheta/sqrt(diag(z$covtheta))[row(z$covtheta)]/
+					sqrt(diag(z$covtheta))[col(z$covtheta)]
+				covcor[lower.tri(covcor)] <- correl[lower.tri(correl)]
+				PrtOutMat(format(round(covcor, digits = 3), width = 10), outf)
+				Report(c('Derivative matrix of expected statistics X by',
+						'parameters and\n'), outf)
+				Report(c("covariance/correlation matrix of X can be found using\n",
+							"summary(ans) within R,",
+							" or by using the 'verbose' option in Siena07.\n "), 
+							sep = "", outf)
+				Report(c("Derivative matrix of expected statistics X by",
                     "parameters:\n\n"), lf)
-           PrtOutMat(z$dfrac, lf)
-           Report('Covariance matrix of X (correlations below the diagonal):\n',
+				PrtOutMat(z$dfrac, lf)
+				Report('Covariance matrix of X (correlations below the diagonal):\n',
                   lf)
-           covcor <- z$msf
-           correl <- z$msf/sqrt(diag(z$msf))[row(z$msf)]/
-               sqrt(diag(z$msf))[col(z$msf)]
-           covcor[lower.tri(covcor)] <- correl[lower.tri(correl)]
-           PrtOutMat(format(round(covcor, digits = 3), width = 10), lf)
-           Report('\n', outf)
-           Report('\n', lf)
-      }
+				covcor <- z$msf
+				correl <- z$msf/sqrt(diag(z$msf))[row(z$msf)]/
+				sqrt(diag(z$msf))[col(z$msf)]
+				covcor[lower.tri(covcor)] <- correl[lower.tri(correl)]
+				PrtOutMat(format(round(covcor, digits = 3), width = 10), lf)
+				Report('\n', outf)
+				Report('\n', lf)
+			}	
+		}
 
 }
