@@ -1,7 +1,7 @@
 #/******************************************************************************
 # * SIENA: Simulation Investigation for Empirical Network Analysis
 # *
-# * Web: http://www.stats.ox.ac.uk/~snidjers/siena
+# * Web: http://www.stats.ox.ac.uk/~snijders/siena
 # *
 # * File: sienaDataCreateFromSession.r
 # *
@@ -233,8 +233,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
     {
         return(getInternals())
     }
-    ActorSets <- NULL
-    ActorSetsSize <- NULL
+	env <- sys.frame(sys.nframe())
     if (!is.null(filename))
     {
         session <- sessionFromFile(filename)
@@ -285,14 +284,14 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                namefiles[[x]][namefiles[[x]] %in% miss] <- NA
                                namefiles[[x]][!(is.na(namefiles[[x]]))
                                               & !(namefiles[[x]] %in%
-                                                  c(nonzero[[x]], 10, 11))] <- 0
+                                               c(nonzero[[x]], 10, 11))] <- 0
                                namefiles[[x]][namefiles[[x]] %in%
                                               nonzero[[x]]] <- 1
                                myarray[ , ,
                                        as.numeric(namesession$Period[x])] <-
                                            namefiles[[x]]
-                               tmp <- sienaNet(myarray, nodeSet=namesession[1,
-                                                        "ActorSet"])
+                               tmp <- sienaDependent(myarray, 
+									nodeSet=namesession[1, "ActorSet"])
                            }
                        }
                        else if (namesession$Format[1] == "Siena net")
@@ -345,8 +344,8 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                         j=y[, 2],
                                         x=y[, 3])
                            } )
-                           tmp <- sienaNet(mylist, nodeSet=namesession[1,
-                                                   "ActorSet"])
+                           tmp <- sienaDependent(mylist, 
+						          nodeSet=namesession[1, "ActorSet"])
                        }
                        else ## pajek net
                        {
@@ -383,19 +382,22 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                if (!is.directed(namefiles[[x]]))
                                {
                                    perm <- c(2, 1, 3)
-                                   myedgelist <- rbind(myedgelist, myedgelist[, perm])
+                                   myedgelist <- rbind(myedgelist, 
+												myedgelist[, perm])
                                }
 
                                if (network.size(namefiles[[x]]) != nActors)
                                    stop("number of actors inconsistent")
 
                                mylist[[x]] <-
-                                   spMatrix(nrow=nActors, ncol=nActors, i= myedgelist[,1], j=myedgelist[,2], x=myedgelist[,3])
+                                   spMatrix(nrow=nActors, ncol=nActors, 
+								   i=myedgelist[,1], j=myedgelist[,2], 
+								   x=myedgelist[,3])
                            }
-                           tmp <- sienaNet(mylist, nodeSet=namesession[1,
+                           tmp <- sienaDependent(mylist, nodeSet=namesession[1,
                                            "ActorSet"])
                        }
-                       assign(objnames[j], tmp, .GlobalEnv)
+                       assign(objnames[j], tmp)
                    },
                    'bipartite' = {
                        nodesets <-
@@ -422,7 +424,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                        as.numeric(namesession$Period[x])] <-
                                            namefiles[[x]]
                            }
-                           tmp <- sienaNet(myarray, type='bipartite',
+                           tmp <- sienaDependent(myarray, type='bipartite',
                                            nodeSet=nodesets)
                        }
                        else if (namesession$Format[1] == "Siena net")
@@ -476,14 +478,14 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                         j=y[, 2],
                                         x=y[, 3])
                            } )
-                           tmp <- sienaNet(mylist, nodeSet=nodesets)
+                           tmp <- sienaDependent(mylist, nodeSet=nodesets)
 
                        }
                        else
                        {
                            stop("Two-mode pajek nets not supported")
                        }
-                   assign(objnames[j], tmp, .GlobalEnv)
+                   assign(objnames[j], tmp)
                    },
                    'behavior' = {
                        ##miss <- gsub(" ", "|",
@@ -495,9 +497,8 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                            namefiles[[1]][namefiles[[1]] %in% miss] <-  NA
                        ##  namefiles[[1]][grep(miss, namefiles[[1]])] <-  NA
                        assign(objnames[j],
-                              sienaNet(namefiles[[1]], type = 'behavior',
-                                       nodeSet=namesession[1, "ActorSet"]),
-                              .GlobalEnv)
+                              sienaDependent(namefiles[[1]], type = 'behavior',
+                                       nodeSet=namesession[1, "ActorSet"]))
                    },
                    'constant covariate' = {
                        ##  miss <- gsub(" ", "|",
@@ -509,11 +510,10 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                        namefiles[[1]][namefiles[[1]] %in% miss] <-  NA
                        varnames <- strsplit(objnames[j], ' ')[[1]]
                        tmp <- sapply(1: ncol(namefiles[[1]]), function(x){
-                           assign(varnames[x],
+                           assign(varnames[x], pos=env,
                                   coCovar(namefiles[[1]][, x],
                                           nodeSet=namesession[1,
-                                          "ActorSet"]),
-                                  .GlobalEnv)})
+                                          "ActorSet"]))})
                    },
                    'changing covariate' = {
                      ##  miss <- gsub(" ", "|",
@@ -525,8 +525,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                        namefiles[[1]][namefiles[[1]] %in% miss] <-  NA
                        assign(objnames[j],
                               varCovar (namefiles[[1]],
-                                        nodeSet=namesession[1, "ActorSet"]),
-                              .GlobalEnv)
+                                        nodeSet=namesession[1, "ActorSet"]))
                    },
                    'constant dyadic covariate' = {
                        miss <- namesession$MissingValues
@@ -564,7 +563,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                              x=myedgelist[, 3])
                            tmp <- coDyadCovar(myval, nodeSets=nodesets)
                        }
-                       assign(objnames[j], tmp, .GlobalEnv)
+                       assign(objnames[j], tmp)
                    },
                    'changing dyadic covariate' = {
                        if (namesession[1, "ActorSet"] == "Actors")
@@ -643,7 +642,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                       )
                          tmp <- varDyadCovar(mylist, nodeSets=nodesets)
                        }
-                       assign(objnames[j], tmp, .GlobalEnv)
+                       assign(objnames[j], tmp)
                    },
                    'exogenous event' = {
                        tmp <- namefiles[[1]]
@@ -668,7 +667,7 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                                   })
                        tmp <- sienaCompositionChange(clist,
                                                      namesession$ActorSet[[1]])
-                       assign(objnames[j], tmp, .GlobalEnv)
+                       assign(objnames[j], tmp)
                    },
                {
                    if (is.null(filename))
@@ -687,9 +686,8 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
         }
         ## create the node sets
         tmp <- lapply(1:length(ActorSets), function(x){
-            assign(ActorSets[x], sienaNodeSet(ActorSetsSize[x],
-                                              nodeSetName=ActorSets[x]),
-                   .GlobalEnv)
+            assign(ActorSets[x], pos=env, sienaNodeSet(ActorSetsSize[x],
+								 nodeSetName=ActorSets[x]))
         })
         ## create the group object
         obj <- unlist(lapply(objnames, strsplit, split=" "))
@@ -704,18 +702,17 @@ sienaDataCreateFromSession <- function (filename=NULL, session=NULL,
                 stop(paste('Duplicate names',
                              obj[duplicated(obj)]))
         }
-        objlist <- mget(obj, .GlobalEnv)
-        nodeSetList <- mget(ActorSets,.GlobalEnv)
+        objlist <- mget(obj, as.environment(-1))
+        nodeSetList <- mget(ActorSets, as.environment(-1))
         names(nodeSetList) <- NULL
        ## arglist <- c(objlist, nodeSets=nodeSetList)
         assign(gps[i], do.call(sienaDataCreate,
-                               c(objlist, nodeSets=list(nodeSetList))),
-               .GlobalEnv)
+                               c(objlist, nodeSets=list(nodeSetList))))
     }
     ##join the groups
     if (length(gps) > 1)
     {
-        mydata <- sienaGroupCreate(mget(gps, .GlobalEnv))
+        mydata <- sienaGroupCreate(mget(gps, as.environment(-1)))
     }
     else
     {
