@@ -6,25 +6,96 @@
 ## * File: sienaprint.r
 ## *
 ## * Description: This file contains the print and summary modules for the
-## * classes siena, sienaFit and sienaModel
+## * classes siena, sienaFit, sienaDependent, sienaAlgorithm, and sienaBayesFit
 ## *
 ## ****************************************************************************/
 ##@print.siena Methods
 print.siena <- function(x, ...)
 {
+    ##@onlys internal print.siena; prints matrix attributes of x$depvar
+	onlys <- function(x, attrib){
+	# function to print the attribute attrib (character string)
+	# of object x$depvars
+	# This attribute must be a logical matrix
+	# with named columns, and rows indicating periods.
+		textattr <- deparse(substitute(attrib),  backtick=FALSE)
+		uponlys <- t(as.matrix(sapply(x$depvars, function(y){attr(y,attrib)})))
+		for (j in 1:dim(uponlys)[2])
+		{
+			if (any(uponlys[,j]))
+			{
+				cat(textattr)
+				cat(":  ", colnames(uponlys)[j], ":    ", sep="")
+				if (all(uponlys[,j]))
+				{
+					cat("all periods\n")
+				}
+				else
+				{
+					word <-
+						ifelse((sum(uponlys[,j]) <= 1), "period ", "periods ")
+					cat(word)
+					cat(which(uponlys[,j]), sep=", ")
+					cat("\n")
+				}
+			}
+		}
+	}
+# begin main method siena.print proper
 	if (!inherits(x, "siena"))
 	{
         stop("not a legitimate Siena data object")
 	}
 	cat('Dependent variables: ', paste(names(x$depvars), collapse=", "), "\n")
-	cat('Number of waves:', x$observations, "\n")
-	if (!is.null(x$nodesets))
+	cat('Number of observations:', x$observations, "\n\n")
+	if (!is.null(x$nodeSet))
 	{
-		tmp <- cbind(c('Nodesets',
-					   paste(names(x$nodesets), collapse=", ")),
-					 c('Number of nodes', sapply(x$nodesets, length)))
-		print(tmp)
+		tmp <- sapply(x$nodeSet, length)
+		if (length(x$nodeSet) <= 1)
+		{
+			tmp <- c('Nodeset        ' = 'Number of nodes', tmp)
+		}
+		else
+		{
+			tmp <- c('Nodesets       ' = 'Number of nodes', tmp)
+		}
+		print(tmp, quote=FALSE)
+		cat("\n")
 	}
+
+	for (j in (1:length(x$depvars)))
+	{
+		xj <- x$depvars[[j]]
+		mymat <- matrix("", 7, 2)
+		mymat[1,] <- c("Dependent variable", attr(xj, "name"))
+		mymat[2,] <- c("Type",               attr(xj, "type"))
+		mymat[3,] <- c("Observations",       attr(xj,  "netdims")[3])
+		if (attr(xj, "type") == "bipartite")
+		{
+			mymat[4,] <- c("First nodeset ", attr(xj, "nodeSet")[1])
+			mymat[5,] <- c("Second nodeset ",attr(xj, "nodeSet")[2])
+			nrows <- 5
+		}
+		else
+		{
+			mymat[4,] <- c("Nodeset ", attr(xj, "nodeSet"))
+			nrows <- 4
+		}
+		if (attr(xj, "type") == "behavior")
+		{
+			mymat[nrows+1,] <- c("Range",
+				paste(attr(xj, "range2"),  collapse=" - "))
+		}
+		else
+		{
+			mymat[nrows+1,] <- c("Densities",
+				paste(signif(attr(xj, "density"), 2),  collapse=" "))
+		}
+		mymat2 <- apply(mymat[0:nrows+1,], 2, format)
+		write.table(mymat2, row.names=FALSE, col.names=FALSE, quote=FALSE)
+		cat("\n")
+	}
+
 	if (length(x$cCovars) > 0)
 	{
 		cat('Constant covariates: ', paste(names(x$cCovars), collapse=", "), "\n")
@@ -44,21 +115,25 @@ print.siena <- function(x, ...)
 		cat('Changing dyadic covariates: ',
 			paste(names(x$dyvCovars), collapse=", "), "\n")
 	}
+
+	onlys(x, 'uponly')
+	onlys(x, 'downonly')
+
 	attrs <- attributes(x)
 	highers <- attrs[["higher"]]
 	disjoints <- attrs[["disjoint"]]
 	atleastones <- attrs[["atLeastOne"]]
 	if (any(highers))
 	{
-		cat("Higher: ", names(highers)[highers], "\n")
+		cat("Higher: ", names(highers)[highers], sep="", "\n")
 	}
 	if (any(disjoints))
 	{
-		cat("Disjoint: ", names(disjoints)[disjoints], "\n")
+		cat("Disjoint: ", names(disjoints)[disjoints], sep="",  "\n")
 	}
 	if (any(atleastones))
 	{
-		cat("atLeatOne: ", names(atleastones)[atleastones], "\n")
+		cat("atLeastOne: ", names(atleastones)[atleastones], sep="",  "\n")
 	}
 	invisible(x)
 }
@@ -77,6 +152,39 @@ print.sienaGroup <- function(x, ...)
 	invisible(x)
 }
 
+print.sienaDependent <- function(x, ...)
+{
+	if (!inherits(x, "sienaDependent"))
+	{
+        stop("not a legitimate Siena dependent variable object")
+	}
+	mymat <- matrix("", 4, 2)
+	mymat[1,] <- c("Type",               attr(x, "type"))
+	mymat[2,] <- c("Observations",       attr(x,  "netdims")[3])
+	if (attr(x, "type") == "bipartite")
+	{
+		mymat[3,] <- c("First nodeset ",
+						paste(attr(x, "nodeSet")[1], " (", attr(x, "netdims")[1],
+							" elements)", sep=""))
+		mymat[4,] <- c("Second nodeset ",
+						paste(attr(x, "nodeSet")[2], " (", attr(x, "netdims")[2],
+							" elements)", sep=""))
+		nrows <- 4
+	}
+	else
+	{
+		mymat[3,] <- c("Nodeset ",
+						paste(attr(x, "nodeSet"), " (", attr(x, "netdims")[1],
+							" elements)", sep=""))
+		nrows <- 3
+	}
+
+	mymat <- apply(mymat, 2, format)
+	write.table(mymat[1:nrows,], row.names=FALSE, col.names=FALSE, quote=FALSE)
+	cat("\n")
+	invisible(x)
+}
+
 ##@print.sienafit Methods
 print.sienaFit <- function(x, tstat=TRUE, ...)
 {
@@ -157,6 +265,8 @@ print.summary.sienaFit <- function(x, ...)
         stop("not a legitimate summary of a Siena model fit")
 	}
 	print.sienaFit(x)
+	cat(c("Overall maximum convergence ratio: ",
+		sprintf("%8.4f", x$tconv.max), "\n\n"))
 	if (sum(x$test) > 0) ## we have some score tests
 	{
 		testn <- sum(x$test)
@@ -246,7 +356,7 @@ print.summary.sienaFit <- function(x, ...)
         }
         cat('\n')
    }
-   if (x$OK)
+   if ((x$OK)&(!is.null(x$covtheta)))
    {
        cat("Covariance matrix of estimates (correlations below diagonal)\n\n")
        covcor <- x$covtheta
@@ -271,13 +381,15 @@ printMatrix <- function(mat)
 {
     cat(mat, sep=c(rep.int(' ', ncol(mat) - 1), '\n'))
 }
-##@print.sienaModel Methods
-print.sienaModel <- function(x, ...)
+##@print.sienaAlgorithm Methods
+print.sienaAlgorithm <- function(x, ...)
 {
-    cat('\n Project name:', x$projname, '\n')
-    cat('\n Use standard initial values:', x$useStdInits, '\n')
+    cat(' Project name:', x$projname, '\n')
+    cat(' Use standard initial values:', x$useStdInits, '\n')
     cat(' Random seed:', x$randomSeed,'\n')
-    cat(' Starting value of gain parameter', x$firstg, '\n')
+    cat(' Starting value of gain parameter:', x$firstg, '\n')
+	cat(' Diagonalization parameter:', x$diagonalize, '\n')
+	cat(' Dolby noise reduction:', x$dolby, '\n')
     if (any(x$MaxDegree > 0))
     {
         cat(' Restrictions on degree in simulations:')
@@ -294,30 +406,36 @@ print.sienaModel <- function(x, ...)
 	}
 	else
 	{
-		if (is.na(x$cconditional) || !x$cconditional)
+		if (is.na(x$cconditional))
 		{
 			cat(" Unconditional simulation if more than one dependent",
 				"variable\n")
 		}
 		else
 		{
-			cat(" Conditional simulation:")
-			if (x$condname != '')
+			if (x$cconditional)
 			{
-				cat('conditioned on', x$condname, '\n')
+				cat(" Conditional simulation:")
+				if (x$condname != '')
+				{
+					cat('conditioned on', x$condname, '\n')
+				}
+				else
+				{
+					if (x$condvarno > 0)
+					{
+						cat('conditioned on variable number', x$condvarno, '\n')
+					}
+				}
 			}
 			else
 			{
-				if (x$condvarno > 0)
-				{
-					cat('conditioned on variable number', x$condvarno, '\n')
-				}
+				cat(" Unconditional simulation\n")
 			}
 		}
 	}
     cat(" Model Type:", ModelTypeStrings[x$modelType], "\n")
     invisible(x)
-
 }
 ##@sienaFitThetaTable Miscellaneous
 sienaFitThetaTable <- function(x, tstat=FALSE)
@@ -399,11 +517,16 @@ sienaFitThetaTable <- function(x, tstat=FALSE)
         addtorow$pos[[addsub]] <- nrates + 2
         addsub <- addsub + 1
     }
-
-    ses <- sqrt(diag(x$covtheta))
-    ses[x$fixed] <- NA
+	if (!is.null(x$covtheta))
+	{
+		ses <- sqrt(diag(x$covtheta))
+		ses[x$fixed] <- NA
+	}
     theta <- x$theta
-    theta[diag(x$covtheta) < 0.0] <- NA
+	if (!is.null(x$covtheta))
+	{
+		theta[diag(x$covtheta) < 0.0] <- NA
+	}
 
     if (nBehavs > 0)
     {
@@ -425,7 +548,10 @@ sienaFitThetaTable <- function(x, tstat=FALSE)
                                                "creat", effects$type)
     mydf[nrates + (1:x$pp), 'text' ] <- effects$effectName
     mydf[nrates + (1:x$pp), 'value' ] <- theta
-    mydf[nrates + (1:x$pp), 'se' ] <- ses
+	if (exists("ses"))
+	{
+		mydf[nrates + (1:x$pp), 'se' ] <- ses
+	}
     if (!is.null(x$tstat))
     {
         mydf[1:nrates, "tstat"] <- NA
@@ -527,6 +653,7 @@ print.xtable.sienaFit <- function(x, ...)
     invisible(x)
 }
 
+##@print.chains.data.frame Methods
 print.chains.data.frame <- function(x, ...)
 {
     NextMethod(x)
@@ -543,3 +670,207 @@ print.chains.data.frame <- function(x, ...)
 		print(endState)
 	}
 }
+
+##@maketemp Methods
+makeTemp <- function(x, ...)
+{
+# This reproduces a part of sienaFit but with Bayesian headings;
+# for use in print.sienaBayesFit and summary.sienaBayesFit
+		name1 <- x$requestedEffects$groupName[1]
+		x$requestedEffects <-
+			x$requestedEffects[x$requestedEffects$groupName==name1,]
+		x$pp <- length(x$theta)
+		x$fixed <- x$fixed[x$effects$groupName==name1]
+		tmp <- sienaFitThetaTable(x)
+		mydf <- tmp$mydf
+		mymat <- as.matrix(mydf[,names(mydf)!="tstat"])
+		mymat[, 'value'] <- format(round(mydf$value, digits=4))
+		mymat[, 'se'] <- format(round(mydf$se, digits=4))
+		mymat[, 'type'] <- format(mymat[, 'type'])
+		mymat[, 'text'] <- format(mymat[, 'text'])
+		mymat[mydf$row < 1, 'row'] <-
+			format(mydf[mydf$row < 1, 'row'])
+		mymat[mydf[,'row'] >= 1, 'row'] <-
+			paste(format(mydf[mydf$row >= 1, 'row']), '.', sep='')
+		mymat <- rbind(c(rep("", 4), "Post.   ", "", "Post.   ", ""),
+					   c(rep("", 4),  "mean    ", "", "s.d.    ", ""),
+						mymat)
+		mymat <- apply(mymat, 2, format)
+		tmp1 <- apply(mymat, 1, function(x) paste(x, collapse=" "))
+		list(tmp, tmp1)
+}
+
+##@print.sienaBayesFit Methods
+print.sienaBayesFit <- function(x, ...)
+{
+	printmat <- function(mat)
+	{
+		cat(sprintf("%8.4f",mat), sep=c(rep.int(' ', ncol(mat) - 1), '\n'))
+	}
+	if (!inherits(x, "sienaBayesFit"))
+	{
+        stop("not a legitimate Siena Bayes model fit")
+	}
+	else
+	{
+		cat("Note: this summary does not contain a convergence check.\n\n")
+		if (length(x$f$groupNames) > 1)
+		{
+			cat("Groups:\n")
+			s <- ""
+			ml <- max(nchar(x$f$groupNames))
+			fmt <- paste("%-", ml+2, "s", sep="")
+			for (i in 1:dim(x$ThinParameters)[2])
+			{
+				s <- paste(s, gettextf(fmt,x$f$groupNames[i]))
+				if ((nchar(s) + ml > 80) | (i == dim(x$ThinParameters)[2]))
+				{
+					cat(paste(s,"\n"))
+					s <- ""
+				}
+			}
+			cat("\n")
+		}
+
+		cat("Posterior means and standard deviations ")
+		# Make temporary changes to make x look like a sienaFit object
+		# so that sienaFitThetaTable can be applied.
+		# This is done in function makeTemp.
+		if (length(x$f$groupNames) <= 1)
+		{
+			cat("\n\n")
+			x$theta <- colMeans(x$ThinParameters[,1,])
+			x$covtheta <- cov(x$ThinParameters[,1,])
+		}
+		else
+		{
+			cat("for global mean parameters\n\n")
+			nmain <- dim(x$ThinPosteriorMu)[1]
+			if (x$frequentist)
+			{
+			first <- nmain - x$lengthPhase3 + 1
+			}
+			else
+			{
+			first <- 1
+			}
+			x$theta <- colMeans(x$ThinPosteriorMu[first:nmain,])
+			x$covtheta <- cov(x$ThinPosteriorMu)
+		}
+		tmps <- makeTemp(x)
+		tmp <- tmps[[1]]
+		tmp1 <- tmps[[2]]
+		addtorow <- tmp$addtorow
+		for (i in 1:length(tmp1))
+		{
+			if (length(addtorow$command) > 0)
+			{
+				for (j in 1:length(addtorow$command))
+				{
+					ii <- match(i-1, addtorow$pos[[j]])
+					if (!is.na(ii))
+						if (i == 2 | addtorow$command[j] == 'Network Dynamics')
+							cat( addtorow$command[j], '\n')
+						else
+							cat('\n', addtorow$command[j], '\n', sep='')
+				}
+			}
+			cat(tmp1[i], '\n')
+		}
+		if (length(x$f$groupNames) > 1)
+		{
+			cat("\n")
+			mean.Sigma <-
+				apply(x$ThinPosteriorSigma[first:nmain,,], c(2,3), mean)
+			sd.Sigma <- apply(x$ThinPosteriorSigma[first:nmain,,], c(2,3), sd)
+			cat("Posterior mean of global covariance matrix\n")
+			printmat(mean.Sigma)
+			cat("\nPosterior standard deviations of ")
+			cat("elements of global covariance matrix\n")
+			printmat(sd.Sigma)
+		}
+		cat("\nTotal of", dim(x$ThinPosteriorMu)[1], "samples.\n\n")
+	}
+	invisible(x)
+}
+
+##@summary.sienaBayesFit Methods
+summary.sienaBayesFit <- function(object, ...)
+{
+    if (!inherits(object, "sienaBayesFit"))
+	{
+        stop("not a legitimate Siena Bayes model fit")
+	}
+    class(object) <- c("summary.sienaBayesFit", class(object))
+    object
+}
+##@print.summary.sienaBayesFit Methods
+print.summary.sienaBayesFit <- function(x, ...)
+{
+	if (!inherits(x, "summary.sienaBayesFit"))
+	{
+        stop("not a legitimate summary of a Siena Bayes model fit")
+	}
+	nmain <- dim(x$ThinPosteriorMu)[1]
+	if (x$frequentist)
+	{
+		cat("Frequentist estimation.\n")
+		first <- nmain - x$lengthPhase3 + 1
+	}
+	else
+	{
+		first <- 1
+		cat("Prior distribution:\n")
+		cat("\nMu      ")
+		for (i in seq(along=x$priorMu))
+		{
+			cat(sprintf("%8.4f", x$priorMu[i,1]),"\n        ")
+		}
+		cat("\nSigma   ")
+		for (i in seq(along=x$priorMu))
+		{
+			cat(sprintf("%8.4f", x$priorSigma[i,]),"\n        ")
+		}
+		cat("\nDf       ",sprintf("%1d", x$priorDf),"\n")
+		if (length(x$f$groupNames) >= 2)
+		{
+			cat("\nKappa  ",sprintf("%8.4f", x$priorKappa),"\n")
+		}
+		cat("\nFor the basic rate parameters, ")
+		cat("the prior is on the square root scale.\n\n")
+	}
+	print.sienaBayesFit(x)
+
+	cat("Posterior means and standard deviations per group\n")
+	for (i in 1:length(x$f$groupNames))
+	{
+		cat("\n", x$f$groupNames[i], "\n")
+		# Make temporary changes to make x look like a sienaFit object
+		# so that sienaFitThetaTable can be applied.
+		# This is done in function makeTemp.
+		x$theta <- colMeans(x$ThinParameters[first:nmain,i,])
+		x$covtheta <- cov(x$ThinParameters[first:nmain,i,])
+		tmps <- makeTemp(x)
+		tmp <- tmps[[1]]
+		tmp1 <- tmps[[2]]
+		addtorow <- tmp$addtorow
+		for (i in 1:length(tmp1))
+		{
+			if (length(addtorow$command) > 0)
+			{
+				for (j in 1:length(addtorow$command))
+				{
+					ii <- match(i-1, addtorow$pos[[j]])
+					if (!is.na(ii))
+						if (i == 2 | addtorow$command[j] == 'Network Dynamics')
+							cat( addtorow$command[j], '\n')
+						else
+							cat('\n', addtorow$command[j], '\n', sep='')
+				}
+			}
+			cat(tmp1[i], '\n')
+		}
+	}
+	invisible(x)
+}
+
