@@ -36,12 +36,16 @@
 #include "IndegreeActivityEffect.h"
 #include "IndegreePopularityEffect.h"
 #include "InInDegreeAssortativityEffect.h"
+#include "InIsolateDegreeEffect.h"
 #include "InOutDegreeAssortativityEffect.h"
 #include "InStructuralEquivalenceEffect.h"
 #include "InteractionCovariateEffect.h"
 #include "InverseOutdegreeEffect.h"
 #include "InverseSquaredOutdegreeEffect.h"
 #include "IsolateEffect.h"
+#include "IsolateNetEffect.h"
+#include "IsolatePopEffect.h"
+#include "JumpCovariateTransitiveTripletsEffect.h"
 #include "LinearShapeEffect.h"
 #include "MainCovariateEffect.h"
 #include "NetworkInteractionEffect.h"
@@ -57,9 +61,12 @@
 #include "ReciprocatedSimilarityEffect.h"
 #include "ReciprocityEffect.h"
 #include "SameCovariateEffect.h"
+#include "SameCovariateTransitiveTripletsEffect.h"
 #include "SimilarityEffect.h"
+#include "SimilarityTransitiveTripletsEffect.h"
 #include "ThreeCyclesEffect.h"
 #include "TransitiveMediatedTripletsEffect.h"
+#include "TransitiveReciprocatedTripletsEffect.h"
 #include "TransitiveTiesEffect.h"
 #include "TransitiveTriadsEffect.h"
 #include "TransitiveTripletsEffect.h"
