@@ -49,6 +49,9 @@ protected:
 	double value(int i) const;
 	bool missing(int i) const;
 	double similarity(int i, int j) const;
+	ConstantCovariate * pConstantCovariate() const;
+	ChangingCovariate * pChangingCovariate() const;
+	BehaviorLongitudinalData * pBehaviorData() const;
 
 private:
 	ConstantCovariate * lpConstantCovariate;
