@@ -45,7 +45,7 @@ public:
 	virtual double calculateContribution(int alter) const;
 
 protected:
-	virtual double statistic(const Network * pSummationTieNetwork) const;
+	virtual double tieStatistic(int alter);
 
 private:
 	// Indicates if the square root of outdegrees must be used
