@@ -18,12 +18,13 @@ namespace siena
 {
 
 /**
- * WW => X closure of covariate effect (see manual).
+ * WW => X closure of covariate effect (see manual);
+ * different values of directionality of W tie out1, out2
  */
 class WWXClosureEffect : public DyadicCovariateDependentNetworkEffect
 {
 public:
-	WWXClosureEffect(const EffectInfo * pEffectInfo);
+	WWXClosureEffect(const EffectInfo * pEffectInfo, bool out1, bool out2);
 	virtual ~WWXClosureEffect();
 
 	virtual void initialize(const Data * pData,
@@ -40,10 +41,14 @@ protected:
 private:
 	void calculateSums(int i, const Network * pNetwork, double * sums) const;
 
-	// For a fixed i, this variable stores the value of sum_h w_{ih} w_{hj} for
-	// each j.
+	// For a fixed i, this variable stores the value for each j of
+	// out1 = out2 = TRUE:  sum_h w_{ih} w_{hj} 
+	// out1 = out2 = FALSE: sum_h w_{hi} w_{jh} 
+	// out1 = FALSE, out2 = TRUE: sum_h w_{hi} w_{hj} 
 
 	double * lsums;
+	bool lout1, lout2;
+
 };
 
 }
